BestCheckpointKeeper
====================

.. currentmodule:: pykeen.checkpoints

.. autoclass:: BestCheckpointKeeper
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~BestCheckpointKeeper.__call__

   .. rubric:: Methods Documentation

   .. automethod:: __call__
